#ifndef HAVE_JTAG_DEFS
#define HAVE_JTAG_DEFS
/*
 * PROM instructions
 */
#define  prm_null_wrd   0X0000
#define  prm_ispen      0X00e8
#define  prm_poll       0X00e3
#define  prm_conld      0X00f0
#define  prm_config_    0X00ee
#define  prm_idcode     0X00fe
#define  ISC_PROGRAM    0X00ea
#define  ISC_ADDR_SHIFT 0X00eb
#define  ISC_ERASE      0X00ec
#define  ISC_DATA_SHIFT 0X00ed
#define  XSC_READ_PROT  0X0004
#define  XSC_DATA_UC    0X0006
#define  XSC_DATA_CC    0X0007
#define  XSC_DATA_DONE  0X0009
#define  XSC_DATA_CCB   0X000c
#define  XSC_DATA_SUCR  0X000e
#define  XSC_READ       0X00ef
#define  XSC_DATA_BTC   0X00f2
#define  XSC_WRT_PROT   0X00f7
#define  XSC_UNLOCK     0Xaa55
#define  prm_bypass     0Xffff

/*
 * JTAG program instruction OpCodes
 */
#define JC_ShI_Imd            0x00
#define JC_ShI_Imd_rbk        0x01
#define JC_ShI_Imd_ver_Imd    0x02
#define JC_ShI_Imd_vermsk_Imd 0x03
#define JC_ShI_Imd_stpupdt    0x0E
#define JC_ShDZ               0x10
#define JC_ShDZrbk            0x11
#define JC_ShDZver_Imd        0x12
#define JC_ShDZverff          0x13
#define JC_ShD_Imd            0x14
#define JC_ShD_Imd_rbk        0x15
#define JC_ShD_Imd_ver_Imd    0x16
#define JC_ShD_Imd_vermsk_Imd 0x17
#define JC_ShDff              0x18
#define JC_ShDffrbk           0x19
#define JC_ShDffverff         0x1B
#define JC_ShDffvermskff      0x1C
#define JC_ShDZstpupdt        0x1D
#define JC_ShD_Imd_stpupdt    0x1E
#define JC_ShDffstpupdt       0x1F
#define JC_SetPollInt         0x20
#define JC_Wait2Poll          0x21
#define JC_TstatLp_Imd        0x22
#define JC_TcntrLp_Imd        0x23
#define JC_TDone              0x24
#define JC_LdLpCntr_Imd       0x25
#define JC_Cont_Data          0x30
#define JC_RstIdl_TAP         0x3D
#define JC_Rst_TAP            0x3E
#define JC_End_Prg            0x3F

/*
 * Default Polling intervals
 */
#define Poll_Dflt  0x3D09
#define Poll_Shrt  0x0075
#define Poll_Long  0x9896

/*
 * JTAG Routines in Program Memory
 */

enum JRTN_ID {JC_Rd_DevID=0, JC_Rd_UC, JC_Rd_CC, JC_Rdbk_PROM, JC_Erase,
              JC_Program, JC_Reload, JC_Verify, JC_Chk_Conn, JC_User, 
              JC_Custom_Rtn=15};

typedef struct jinstr_t {  /* JTAG Instructions */
  unsigned char instr;
  unsigned short bc;
  unsigned short data;
} JINSTR_t;

typedef struct jrtn_t {  /* JTAG Routines */
  int jid;
  short n;
  unsigned short base;
  JINSTR_t *rtn;
} JRTN_t;

typedef struct verify_t {  /* JTAG Verify data */
  unsigned short int *buf;
  int nw;
} VERIFY_t;


extern void jtag_init();
extern unsigned int read_dev_id();
extern unsigned int read_user_code();
extern char *read_customer_code();
extern int erase_prom();
extern int chk_jtag_conn();
extern void program_prom_cmd();
extern void reload_fpga();
extern void verify_prom_cmd();
extern void ld_rtn_base_addr(unsigned short );
extern void exec_routine(enum JRTN_ID );
extern unsigned int get_jtag_status();
extern void abort_jtag_cmnds();
extern void write_jtag_fifo_words(unsigned short *, int );
extern void write_jtag_fifo_bytes(unsigned char *, int );
extern int read_prg_space(unsigned short );
extern void print_routines();
extern void rd_back_prom();
extern void read_mcs(char *fn);
extern void send_ver_prom_data();
extern void send_prg_prom_data();
extern void send_uc_cc_data(char *fn);

#endif

